clear
capture log close
set more off


*** Global
global root "C:\Users\walke\Dropbox\Shipbuilding project\JEEA_replication_files"

global temp "$root\temp"


**** Load main data 
use "$root\data\analysis_data_location_decade_power_long", clear

** Focus on US and Canada only
count
keep if country=="US" | country=="CANADA"
keep if region=="atlantic" | region=="great lakes"
drop if decade<1850
count

** Merge in area TT
sort country state county
merge m:1 country state county using "$temp\county_area_tt"
tab _merge
drop _merge
replace area="ottawa" if location=="Temiscaming"
encode area, gen(area_code)

*** Treat DC as the same as Maryland
replace state="MD" if state=="DC"

**** Merge in iron and wood price controls
sort state
merge m:1 state using "$root\data\controls_lumber_prices"
tab _merge
drop if _merge==2
drop _merge
rename lumber_price_weighted lumber_pr_w
rename lumber_price_unweighted lumber_pr_uw

sort state
merge m:1 state using "$root\data\controls_iron_prices"
tab _merge
drop if _merge==2
drop _merge 

**** Merge in local industrial composition
replace county=upper(county)
sort country state county
merge m:1 country state county using "$root\data\controls_county_metalworking"
tab _merge
drop if _merge==2
drop _merge

gen ln_county_pop=ln(county_pop)
gen ln_county_metal_emp=ln(metal_emp)
gen ln_county_lumber_emp=ln(lumber_emp)

gen county_metal_shr=metal_emp/county_pop
gen county_lumber_shr=lumber_emp/county_pop

** 
replace state="DC" if state=="MD" & location=="Washington"
drop max_tons_ 

reshape wide tons_ , i(country location state region ship_material power latitude longitude dist_naval_shipyard) j(decade)


** generate unique location identifiers
gen lc=location+"_"+country+"_"+state
encode lc, gen(loc_code)

** fillin locations
count
fillin loc_code ship_material power
count

order loc_code ship_material power
gsort loc_code -ship_material -power


foreach i in country location state region {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==""
}

foreach i in latitude longitude dist_naval_shipyard iron_price lumber_pr_w lumber_pr_uw {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==.
}

gsort loc_code ship_material power

foreach i in country location state region {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==""
}

foreach i in latitude longitude dist_naval_shipyard iron_price lumber_pr_w lumber_pr_uw {
replace `i'=`i'[_n-1] if loc_code==loc_code[_n-1] & `i'==.
}



forval i = 1850(10)1900 {
rename tons_`i' tons_`i's
replace tons_`i's=0 if tons_`i's==.
}

gen us_flag=0
replace us_flag=1 if country=="US" & region=="atlantic"
gen great_lakes=0
replace great_lakes=1 if region=="great lakes"

forval i = 1850(10)1900 {
gen ln_tons_`i's=ln(tons_`i's)

gen act_`i'=0
replace act_`i'=1 if tons_`i's>0
bysort loc_code: egen act_loc_`i'=max(act_`i')

bysort loc_code: egen tons_loc_`i'=sum(tons_`i's)
gen ln_tons_loc_`i'=ln(tons_loc_`i')

}



gen iron=0
replace iron=1 if ship_material=="iron"
gen us_flag_iron=us_flag*iron
gen great_lakes_iron=great_lakes*iron

gen steam=0
replace steam=1 if power=="steam"
gen iron_steam=iron*steam
gen lakes_steam=great_lakes*steam
gen us_steam= us_flag*steam
gen lakes_iron_steam=great_lakes*iron*steam
gen us_iron_steam=us_flag*iron*steam


** change tons to 1000s
replace tons_1850s=tons_1850s/10000
replace tons_loc_1850=tons_loc_1850/10000

replace tons_1870s=tons_1870s/10000
replace tons_loc_1870=tons_loc_1870/10000


***** log prices
gen ln_iron_price=ln(iron_price)
gen ln_lumber_price_weighted=ln(lumber_pr_w)
gen ln_lumber_price_unweighted=ln(lumber_pr_uw)
gen iron_price_inter=ln_iron_price*iron
gen wood_price_inter=ln_lumber_price_weighted*iron
gen wood_price_inter_uw=ln_lumber_price_unweighted*iron

gen relative_price=iron_price/lumber_pr_w
gen log_rel_price=ln(relative_price)
gen log_rel_price_inter=log_rel_price*iron


** label variables
label variable iron "Metal indicator"
label variable us_flag "U.S. indicator"
label variable great_lakes "Great Lakes indicator"
label variable us_flag_iron "U.S. x Metal indicator"
label variable great_lakes_iron "Great Lakes x Metal indicator"
label variable act_1870 "Active in the same sector-location in 1871-80"
label variable act_loc_1870 "Active shipbuilding location in 1871-80"
label variable tons_1870s "Tons in the same sector-location in 1871-80"
label variable tons_loc_1870 "Total tons in the location in 1871-80"

label variable act_1850 "Active in the same sector-location in 1851-60"
label variable act_loc_1850 "Active shipbuilding location in 1851-60"
label variable tons_1850s "Tons in the same sector-location in 1851-60"
label variable tons_loc_1850 "Total tons in the location in 1851-60"

label variable ln_iron_price "Log iron price"
label variable ln_lumber_price_weighted "Log lumber price"
label variable iron_price_inter "Log iron price x Metal"
label variable wood_price_inter "Log lumber price x Metal"


*** REGRESSIONS

** steam only
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron if act_1900==1 & power=="steam", cluster(loc_code)
est store L1

** steam only controls
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron act_1870  act_loc_1870 tons_1870s tons_loc_1870 ln_county_pop county_metal_shr county_lumber_shr if act_1900==1 & power=="steam", cluster(loc_code)
est store L2

** sail only
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron if act_1900==1 & power=="sail", cluster(loc_code)
est store L3

** sail only controls
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron act_1870  act_loc_1870 tons_1870s tons_loc_1870 ln_county_pop county_metal_shr county_lumber_shr if act_1900==1 & power=="sail", cluster(loc_code)
est store L4

** combined
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron iron_steam lakes_steam us_steam lakes_iron_steam us_iron_steam if act_1900==1, cluster(loc_code)
est store L5

** combined controls
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron iron_steam lakes_steam us_steam  lakes_iron_steam us_iron_steam act_1870  act_loc_1870 tons_1870s tons_loc_1870 ln_county_pop county_metal_shr county_lumber_shr if act_1900==1, cluster(loc_code)
est store L6

outreg2 [L1 L2 L3 L4 L5 L6] using "$root\appendix_tables_figures\Table_A13\Table_A13", tex drop(_I*) replace label


*** REGRESSIONS - clustered by area

** steam only
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron if act_1900==1 & power=="steam", cluster(area_code)
est store L1

** steam only controls
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron act_1870  act_loc_1870 tons_1870s tons_loc_1870 ln_county_pop county_metal_shr county_lumber_shr if act_1900==1 & power=="steam", cluster(area_code)
est store L2

** sail only
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron if act_1900==1 & power=="sail", cluster(area_code)
est store L3

** sail only controls
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron act_1870  act_loc_1870 tons_1870s tons_loc_1870 ln_county_pop county_metal_shr county_lumber_shr if act_1900==1 & power=="sail", cluster(area_code)
est store L4

** combined
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron iron_steam lakes_steam us_steam lakes_iron_steam us_iron_steam if act_1900==1, cluster(area_code)
est store L5

** combined controls
reg ln_tons_1900s iron us_flag great_lakes us_flag_iron great_lakes_iron iron_steam lakes_steam us_steam  lakes_iron_steam us_iron_steam act_1870  act_loc_1870 tons_1870s tons_loc_1870 ln_county_pop county_metal_shr county_lumber_shr if act_1900==1, cluster(area_code)
est store L6

outreg2 [L1 L2 L3 L4 L5 L6] using "$root\appendix_tables_figures\Table_A13\Table_A13_clustered_by_area", tex drop(_I*) replace label

****
