clear
capture log close
set more off


*** Global
global root "C:\Users\walke\Dropbox\Shipbuilding project\JEEA_replication_files"

global temp "$root\temp"


****
use "$root\data\analysis_data_location_decade_long", clear


** Focus on US & Canada East
count
keep if country=="US" | country=="CANADA"
keep if region=="atlantic" | region=="great lakes"
drop if decade<1850
count

** Merge in area TT
sort country state county
merge m:1 country state county using "$temp\county_area_tt"
tab _merge
drop _merge
replace area="ottawa" if location=="Temiscaming"
encode area, gen(area_code)


*** Treat DC as the same as Maryland
replace state="MD" if state=="DC"

**** Merge in iron and wood price controls
sort state
merge m:1 state using "$root\data\controls_lumber_prices"
tab _merge
drop if _merge==2
drop _merge
rename lumber_price_weighted lumber_pr_w
rename lumber_price_unweighted lumber_pr_uw

sort state
merge m:1 state using "$root\data\controls_iron_prices"
tab _merge
drop if _merge==2
drop _merge

**** Merge in local industrial composition
replace county=upper(county)
sort country state county
merge country state county using "$root\data\controls_county_metalworking"
tab _merge
drop if _merge==2
drop _merge

*** Treat DC as the same as Maryland
replace state="DC" if state=="MD" & location=="Washington, DC"


gen ln_county_pop=ln(county_pop)
gen ln_county_metal_emp=ln(metal_emp)
gen ln_county_lumber_emp=ln(lumber_emp)

gen county_metal_shr=metal_emp/county_pop
gen county_lumber_shr=lumber_emp/county_pop

**
replace state="DC" if state=="MD" & location=="Washington"


** 
drop max_tons
reshape wide tons_, i(country location state region decade latitude longitude dist_naval_shipyard) j(ship_material) string
replace tons_wood=0 if tons_wood==.
replace tons_iron=0 if tons_iron==.


** generate activity variable
gen active_=0
replace active_=1 if tons_wood>0 & tons_iron==0
replace active_=2 if tons_iron>0 & tons_wood==0
replace active_=3 if tons_iron>0 & tons_wood>0

* generate activity by type variable
gen act_wood_=0
replace act_wood_=1 if tons_wood>0

gen act_iron_=0
replace act_iron_=1 if tons_iron>0

*** Put in 1000s of tons
replace tons_wood=tons_wood/1000
replace tons_iron=tons_iron/1000



** reshape by decade
rename tons_wood tons_wood_
rename tons_iron tons_iron_
reshape wide active_ tons_wood_ tons_iron_ act_wood_ act_iron_, i(country location state region latitude longitude dist_naval_shipyard) j(decade)

preserve
use "$root\data\nearby_tons_US_CA_LONG", clear
reshape wide tons_1840s_50km-tons_1900s_150km, i(country location state) j(ship_material) string
sort location country state 
save "$temp\nearby_tons_US_CA_LONG", replace
restore


** Merge in nearby tonnage data
sort location country state
merge 1:1 location country state using "$temp\nearby_tons_US_CA_LONG"
tab _merge
drop if _merge==2
drop _merge

forval i=1850(10)1900 {
replace tons_`i's_50kmiron=tons_`i's_50kmiron/1000
replace tons_`i's_50kmwood=tons_`i's_50kmwood/1000
replace tons_`i's_100kmiron=tons_`i's_100kmiron/1000
replace tons_`i's_100kmwood=tons_`i's_100kmwood/1000
}

*** generate full location tonnage
forval i=1850(10)1900 {
gen tons_loc_`i'=tons_iron_`i'+tons_wood_`i'
gen tons_50km_`i'=tons_`i's_50kmiron + tons_`i's_50kmwood
gen tons_100km_`i'=tons_`i's_100kmiron + tons_`i's_100kmwood
}


** generate unique location identifiers
gen lc=location+"_"+country+"_"+state
encode lc, gen(loc_code)


gen us_flag=0
replace us_flag=1 if country=="US" & region=="atlantic"
gen great_lakes=0
replace great_lakes=1 if region=="great lakes"
gen great_lakes_US=0
replace great_lakes_US=1 if region=="great lakes" & country=="US"
gen great_lakes_CA=0
replace great_lakes_CA=1 if region=="great lakes" & country=="CANADA"


gen nearby_navy_50=0
replace nearby_navy_50=1 if dist_naval_shipyard<50

gen nearby_navy_100=0
replace nearby_navy_100=1 if dist_naval_shipyard>=50 & dist_naval_shipyard<100

gen lat_sq=latitude*latitude
gen lon_sq=longitude*longitude

***** log prices
gen ln_iron_price=ln(iron_price)
gen ln_lumber_price_weighted=ln(lumber_pr_w)
gen ln_lumber_price_unweighted=ln(lumber_pr_uw)
gen iron_price_inter=ln_iron_price*iron

gen relative_price=iron_price/lumber_pr_w
gen log_rel_price=ln(relative_price)


** label variables
label variable us_flag "U.S. indicator"
label variable great_lakes "Great Lakes indicator"



*** NAVY SHIPYARD MULTINOMIAL REGRESSIONS
* 0 = inactive ; 1 = wood only ; 2 = iron only ; 3 = iron and wood active
* Probability a location is active in a sector in 1900 depending on US and Great Lakes flags
mlogit active_1900 nearby_navy_50 if country=="US" & region=="atlantic"
est store R1
test [1]nearby_navy_50=[2]nearby_navy_50
test [1]nearby_navy_50=[3]nearby_navy_50

* Now controlling for nearby production
mlogit active_1900 nearby_navy_50 act_wood_1870 act_iron_1870 tons_wood_1870 tons_iron_1870 tons_1870s_100kmiron tons_1870s_100kmwood if country=="US" & region=="atlantic"
est store R2
test [1]nearby_navy_50=[2]nearby_navy_50
test [1]nearby_navy_50=[3]nearby_navy_50

* With county-level controls
mlogit active_1900 nearby_navy_50 act_wood_1870 act_iron_1870 tons_wood_1870 tons_iron_1870 tons_1870s_100kmiron tons_1870s_100kmwood ln_county_pop county_metal_shr county_lumber_shr if country=="US" & region=="atlantic"
est store R3
test [1]nearby_navy_50=[2]nearby_navy_50
test [1]nearby_navy_50=[3]nearby_navy_50

* With 100km band
mlogit active_1900 nearby_navy_50 nearby_navy_100 act_wood_1870 act_iron_1870 tons_wood_1870 tons_iron_1870 tons_1870s_100kmiron tons_1870s_100kmwood ln_county_pop county_metal_shr county_lumber_shr if country=="US" & region=="atlantic"
est store R4
test [1]nearby_navy_50=[2]nearby_navy_50
test [1]nearby_navy_50=[3]nearby_navy_50


estout R1 R2 R3 R4 using "$root\appendix_tables_figures\Table_A18\Table_A18.tex", replace style(tex) s(ll chi2 N) label legend c(b(star fmt(%9.3f)) se(par fmt(%9.3f)))



*** NAVY SHIPYARD MULTINOMIAL REGRESSIONS -- clustered by area
* 0 = inactive ; 1 = wood only ; 2 = iron only ; 3 = iron and wood active
* Probability a location is active in a sector in 1900 depending on US and Great Lakes flags
mlogit active_1900 nearby_navy_50 if country=="US" & region=="atlantic", vce(cluster area_code)
est store R1
test [1]nearby_navy_50=[2]nearby_navy_50
test [1]nearby_navy_50=[3]nearby_navy_50

* Now controlling for nearby production
mlogit active_1900 nearby_navy_50 act_wood_1870 act_iron_1870 tons_wood_1870 tons_iron_1870 tons_1870s_100kmiron tons_1870s_100kmwood if country=="US" & region=="atlantic", vce(cluster area_code)
est store R2
test [1]nearby_navy_50=[2]nearby_navy_50
test [1]nearby_navy_50=[3]nearby_navy_50

* With county-level controls
mlogit active_1900 nearby_navy_50 act_wood_1870 act_iron_1870 tons_wood_1870 tons_iron_1870 tons_1870s_100kmiron tons_1870s_100kmwood ln_county_pop county_metal_shr county_lumber_shr if country=="US" & region=="atlantic", vce(cluster area_code)
est store R3
test [1]nearby_navy_50=[2]nearby_navy_50
test [1]nearby_navy_50=[3]nearby_navy_50

* With 100km band
mlogit active_1900 nearby_navy_50 nearby_navy_100 act_wood_1870 act_iron_1870 tons_wood_1870 tons_iron_1870 tons_1870s_100kmiron tons_1870s_100kmwood ln_county_pop county_metal_shr county_lumber_shr if country=="US" & region=="atlantic", vce(cluster area_code)
est store R4
test [1]nearby_navy_50=[2]nearby_navy_50
test [1]nearby_navy_50=[3]nearby_navy_50


estout R1 R2 R3 R4 using "$root\appendix_tables_figures\Table_A18\Table_A18_clustered_by_area.tex", replace style(tex) s(ll chi2 N) label legend c(b(star fmt(%9.3f)) se(par fmt(%9.3f)))



***
