clear
capture log close
set more off


*** Global
global root "C:\Users\walke\Dropbox\Shipbuilding project\JEEA_replication_files"

global temp "$root\temp"


****
use "$root\data\analysis_data_location_decade_power_long", clear

** Focus on US & Canada East
count
keep if country=="US"  | country=="CANADA"
keep if region=="atlantic" | region=="great lakes"
drop if decade<1850
count

** Merge in area TT
sort country state county
merge m:1 country state county using "$temp\county_area_tt"
tab _merge
drop _merge
replace area="ottawa" if location=="Temiscaming"
encode area, gen(area_code)

** Generate unique material x power identifiers
generate material_power=ship_material+"_"+power
drop ship_material power

** 
drop max_tons
reshape wide tons_, i(country location state region decade latitude longitude dist_naval_shipyard) j(material_power) string
replace tons_wood_sail=0 if tons_wood_sail==.
replace tons_iron_sail=0 if tons_iron_sail==.
replace tons_wood_steam=0 if tons_wood_steam==.
replace tons_iron_steam=0 if tons_iron_steam==.



** generate activity variable
gen active_=0
replace active_=1 if tons_wood_sail>0 
replace active_=2 if tons_wood_steam>0 
replace active_=3 if tons_iron_sail>0 
replace active_=4 if tons_iron_steam>0 


* generate activity by type variable
gen act_wood_=0
replace act_wood_=1 if tons_wood_steam>0 | tons_wood_sail>0

gen act_iron_=0
replace act_iron_=1 if tons_iron_steam>0 | tons_iron_sail>0

gen act_sail_=0
replace act_sail_=1 if tons_iron_sail>0 | tons_wood_sail>0

gen act_steam_=0
replace act_steam_=1 if tons_iron_steam>0 | tons_wood_steam>0


*** Put in 1000s of tons
replace tons_wood_sail=tons_wood_sail/1000
replace tons_iron_sail=tons_iron_sail/1000
replace tons_wood_steam=tons_wood_steam/1000
replace tons_iron_steam=tons_iron_steam/1000

** reshape by decade
rename tons_wood_sail tons_wood_sail_
rename tons_wood_steam tons_wood_steam_
rename tons_iron_sail tons_iron_sail_
rename tons_iron_steam tons_iron_steam_

reshape wide active_ tons_wood_sail tons_wood_steam tons_iron_sail tons_iron_steam act_wood_ act_iron_ act_sail_ act_steam_, i(country location state region latitude longitude dist_naval_shipyard) j(decade)



preserve
use "$root\data\nearby_tons_US_CA_LONG", clear
reshape wide tons_1840s_50km-tons_1900s_150km, i(country location state) j(ship_material) string
sort location country state 
save "$temp\nearby_tons_US_CA_LONG", replace
restore


** Merge in nearby tonnage data
sort location country state
merge 1:1 location country state using "$temp\nearby_tons_US_CA_LONG"
tab _merge
drop if _merge==2
drop _merge

**** Merge in local industrial composition
replace state="MD" if state=="DC"
replace county=upper(county)
sort country state county
merge country state county using "$root\data\controls_county_metalworking"
tab _merge
drop if _merge==2
drop _merge
replace state="DC" if state=="MD" & location=="Washington, DC"

gen ln_county_pop=ln(county_pop)
gen ln_county_metal_emp=ln(metal_emp)
gen ln_county_lumber_emp=ln(lumber_emp)

gen county_metal_shr=metal_emp/county_pop
gen county_lumber_shr=lumber_emp/county_pop

*** generate full location tonnage
forval i=1850(10)1900 {
gen tons_loc_`i'=tons_iron_sail_`i'+ tons_iron_steam_`i'+tons_wood_sail_`i'+tons_wood_steam_`i'
gen tons_50km_`i'=tons_`i's_50kmiron + tons_`i's_50kmwood
gen tons_100km_`i'=tons_`i's_100kmiron + tons_`i's_100kmwood
}


** generate unique location identifiers
gen lc=location+"_"+country+"_"+state
encode lc, gen(loc_code)

gen us_flag=0
replace us_flag=1 if country=="US" & region=="atlantic"
gen great_lakes=0
replace great_lakes=1 if region=="great lakes"


** label variables
label variable us_flag "U.S. Coastal"
label variable great_lakes "Great Lakes"



*** REGRESSION TYPE 1: Multinomial logit
* 0 = inactive ; 1 = wood sailing ships ; 2 = wood steamships 3 = iron sailing ; 4 = iron steam
* Probability a location is active in a sector in 1900 depending on US and Great Lakes flags
mlogit active_1900 us_flag great_lakes 
est store R1
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes

mlogit active_1900 us_flag great_lakes act_wood_1870 act_iron_1870 
est store R2
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes

mlogit active_1900 us_flag great_lakes  tons_wood_sail_1870 tons_iron_sail_1870 tons_wood_steam_1870 tons_iron_steam_1870  
est store R3
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes

* Now controlling for nearby production
mlogit active_1900 us_flag great_lakes tons_wood_sail_1870 tons_iron_sail_1870 tons_wood_steam_1870 tons_iron_steam_1870  tons_1870s_100kmwood tons_1870s_100kmiron
est store R4
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes

* Now controlling for nearby production
mlogit active_1900 us_flag great_lakes tons_wood_sail_1870 tons_iron_sail_1870 tons_wood_steam_1870 tons_iron_steam_1870  tons_1870s_100kmwood tons_1870s_100kmiron ln_county_pop county_metal_shr county_lumber_shr
est store R5
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes

estout R1 R2 R3 R4 R5 using "$root\appendix_tables_figures\Table_A9\Table_A9.tex", replace style(tex) s(ll chi2 N) label legend c(b(star fmt(%9.3f)) se(par fmt(%9.3f)))


*** REGRESSION TYPE 1b: Multinomial logit, clustered by area
* 0 = inactive ; 1 = wood sailing ships ; 2 = wood steamships 3 = iron sailing ; 4 = iron steam
* Probability a location is active in a sector in 1900 depending on US and Great Lakes flags
mlogit active_1900 us_flag great_lakes , vce(cluster area_code)
est store R1
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes


mlogit active_1900 us_flag great_lakes act_wood_1870 act_iron_1870, vce(cluster area_code)
est store R2
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes

mlogit active_1900 us_flag great_lakes  tons_wood_sail_1870 tons_iron_sail_1870 tons_wood_steam_1870 tons_iron_steam_1870, vce(cluster area_code)
est store R3
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes

* Now controlling for nearby production
mlogit active_1900 us_flag great_lakes tons_wood_sail_1870 tons_iron_sail_1870 tons_wood_steam_1870 tons_iron_steam_1870  tons_1870s_100kmwood tons_1870s_100kmiron, vce(cluster area_code)
est store R4
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes

* Now controlling for nearby production
mlogit active_1900 us_flag great_lakes tons_wood_sail_1870 tons_iron_sail_1870 tons_wood_steam_1870 tons_iron_steam_1870  tons_1870s_100kmwood tons_1870s_100kmiron ln_county_pop county_metal_shr county_lumber_shr, vce(cluster area_code)
est store R5
test [1]great_lakes=[3]great_lakes
test [2]great_lakes=[4]great_lakes


estout R1 R2 R3 R4 R5 using "$root\appendix_tables_figures\Table_A9\Table_A9_clustered.tex", replace style(tex) s(ll chi2 N) label legend c(b(star fmt(%9.3f)) se(par fmt(%9.3f)))



*****
